@@ -3,7 +3,11 @@ import os, struct
 verbose = True
 verbose = False
 
-afs_home = os.path.join('afs', 'ipp-garching.mpg.de/home')
+if os.name == 'nt':
+    afs_home = '\/afs/ipp-garching.mpg.de/home'
+else:
+    afs_home = '/afs/ipp-garching.mpg.de/home'
+
 
 def sf_path(nshot, diag, exp='AUGD', ed=0):
 
