@@ -86,7 +86,7 @@ def getlastshot():
     return nshot
 
 
-def get_cti_ts06(nshot):
+def getcti_ts06(nshot):
     """
     Gets the absolute time (ns) of a discharge trigger 
     """
@@ -106,7 +106,7 @@ def get_cti_ts06(nshot):
     return ts06
 
 
-def get_gc(nshot=30136):
+def getgc(nshot=30136):
     """
     Returns first wall contours for plotting
     """
@@ -121,23 +121,24 @@ def get_gc(nshot=30136):
         flag_use = ygc.getobject('ixplin')
         gcnames  = ygc.getobject('chGCnm')
 
-    comp_r = {}
-    comp_z = {}
+    comp_d = {}
 
     inxbeg = np.cumsum(np.append(0, inxlen))
 
     if gcnames is None:
         for jcom, leng in enumerate(inxlen):
-            comp_r[jcom] = rrgc[inxbeg[jcom]:inxbeg[jcom+1]]
-            comp_z[jcom] = zzgc[inxbeg[jcom]:inxbeg[jcom+1]]
+            comp_d[jcom] = type('', (), {})() # empty object
+            comp_d[jcom].r = rrgc[inxbeg[jcom]: inxbeg[jcom+1]]
+            comp_d[jcom].z = zzgc[inxbeg[jcom]: inxbeg[jcom+1]]
     else:
         for jcom, lbl in enumerate(gcnames):
             lbl = str_byt.to_str(lbl)
             if flag_use[jcom] > 0:
-                comp_r[lbl] = rrgc[inxbeg[jcom]:inxbeg[jcom+1]]
-                comp_z[lbl] = zzgc[inxbeg[jcom]:inxbeg[jcom+1]]
+                comp_d[lbl] = type('', (), {})()
+                comp_d[lbl].r = rrgc[inxbeg[jcom]: inxbeg[jcom+1]]
+                comp_d[lbl].z = zzgc[inxbeg[jcom]: inxbeg[jcom+1]]
     
-    return comp_r, comp_z
+    return comp_d
 
 
 class SFREAD:
@@ -256,7 +257,7 @@ class SFREAD:
         if otyp == 8:
             return self.getobject(obj)
         elif otyp in (6, 7, 13):
-            rels = self.get_rel_names(obj)
+            rels = self.getrelnames(obj)
             for rel in rels:
                 if self.sfh[rel].obj_type == 8:
                     return self.getobject(rel)
@@ -274,7 +275,7 @@ class SFREAD:
         if otyp == 13:
             return self.getobject(obj)
         elif otyp in (6, 7):
-            rels = self.get_rel_names(obj)
+            rels = self.getrelnames(obj)
             for rel in rels:
                 if self.sfh[rel].obj_type == 13:
                     return self.getobject(rel)
@@ -341,7 +342,7 @@ class SFREAD:
 
 # LongLong in [ns] and no zero at TS06
                 if otyp == 8 and dfmt == 13: # RMC:TIME-AD0
-                    dout = 1e-9*(data - self.get_ts06())
+                    dout = 1e-9*(data - self.getts06())
                 else:
                     dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
 
@@ -374,7 +375,7 @@ class SFREAD:
         Returns the time-array in [s] for TB of type PPG_prog
         """
 
-        for rel in self.get_rel_names(tbobj):
+        for rel in self.getrelnames(tbobj):
             if self.sfh[rel].obj_type == 3:
                 ppg = self.getdevice(rel)
                 if 'PRETRIG' in ppg.keys():
@@ -408,7 +409,7 @@ class SFREAD:
         Returns coefficients for signal(group) calibration
         """
         obj = str_byt.to_str(obj)
-        for rel in self.get_rel_names(obj):
+        for rel in self.getrelnames(obj):
             if self.sfh[rel].obj_type == 4:
                 caltyp = str_byt.to_str(sfdics.cal_type[self.sfh[rel].cal_type])
                 if caltyp == 'LinCalib':
@@ -436,7 +437,7 @@ class SFREAD:
         for j in range(sfo.items):
             pname = str_byt.to_str(buf[j0: j0+8])
             unit, dfmt, n_items = unpack('>3H', buf[j0+8:  j0+14])
-            meta = sfobj.EMPTY()
+            meta = type('', (), {})()
 #            meta.phys_unit = sfdics.unit_d[unit]
             meta.data_format = dfmt
             if verbose:
@@ -486,7 +487,7 @@ class SFREAD:
         sfmt = sfdics.fmt2struc[dfmt]
         list_ids = unpack('>%d%s' %(sfo.items, sfmt), buf)
 
-        return [self.get_obj_name(jid) for jid in list_ids]
+        return [self.getobjname(jid) for jid in list_ids]
 
 
     def getlist_by_type(self, obj_type=7):
@@ -494,7 +495,7 @@ class SFREAD:
         return [lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type == obj_type]
 
 
-    def get_obj_name(self, jobj):
+    def getobjname(self, jobj):
         """
         Returns the object name for an inpur object ID
         """
@@ -502,7 +503,7 @@ class SFREAD:
         return self.sfh['obj_nam'][jobj]
 
 
-    def get_obj_id(self, lbl):
+    def getobjid(self, lbl):
         """
         Returns the object ID for a given objeect
         """
@@ -511,14 +512,14 @@ class SFREAD:
         return self.sfh['obj_id'][lbl]
 
 
-    def get_rel_names(self, lbl):
+    def getrelnames(self, lbl):
         """
         Returns the relation names of a given object
         """
 
         lbl = str_byt.to_str(lbl)
         rels_id = self.sfh[lbl].rel
-        return [self.get_obj_name(jobj) for jobj in rels_id if jobj < 65535]
+        return [self.getobjname(jobj) for jobj in rels_id if jobj < 65535]
 
 
     def getdevice(self, lbl):
@@ -529,7 +530,7 @@ class SFREAD:
         return self.getparset(lbl)
 
 
-    def get_ts06(self):
+    def getts06(self):
         """
         Reads the diagnostic internal TS06 from parameter set
         """
@@ -542,7 +543,7 @@ class SFREAD:
                     break
 
         if ts6 == 0:
-            ts6 = get_cti_ts06(self.shot)
+            ts6 = getcti_ts06(self.shot)
 
         return ts6
 
@@ -559,7 +560,7 @@ class SFREAD:
         if otyp != 6:
             return False # Objects other than sig, sgr, tbase
 
-        rels = self.get_rel_names(obj)
+        rels = self.getrelnames(obj)
         for rel in rels:
             if self.sfh[rel].obj_type == 8:
                 shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
@@ -584,7 +585,7 @@ class SFREAD:
         if otyp != 6:
             return False # Objects other than sig, sgr, tbase
 
-        rels = self.get_rel_names(obj)
+        rels = self.getrelnames(obj)
         for rel in rels:
             if self.sfh[rel].obj_type == 8:
                 shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
